# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetDefaultTagsResult',
    'AwaitableGetDefaultTagsResult',
    'get_default_tags',
]

@pulumi.output_type
class GetDefaultTagsResult:
    """
    A collection of values returned by getDefaultTags.
    """
    def __init__(__self__, id=None, tags=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, str]:
        """
        Blocks of default tags set on the provider. See details below.
        """
        return pulumi.get(self, "tags")


class AwaitableGetDefaultTagsResult(GetDefaultTagsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDefaultTagsResult(
            id=self.id,
            tags=self.tags)


def get_default_tags(tags: Optional[Mapping[str, str]] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDefaultTagsResult:
    """
    Use this data source to access information about an existing resource.

    :param Mapping[str, str] tags: Blocks of default tags set on the provider. See details below.
    """
    __args__ = dict()
    __args__['tags'] = tags
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = _utilities.get_version()
    __ret__ = pulumi.runtime.invoke('aws:index/getDefaultTags:getDefaultTags', __args__, opts=opts, typ=GetDefaultTagsResult).value

    return AwaitableGetDefaultTagsResult(
        id=__ret__.id,
        tags=__ret__.tags)
